@@ -321,20 +321,20 @@ class StockDetail( object ):
         info = dict()
         try:
             details = self.get_obv_details().tail(1)
-            info['OBV Value']         = round(details['OBV'].values[0],2)
-            info['OBV Index']         = round(details['OBV Index'].values[0],2)
-            info['OBV Slope']         = round(details['OBV Index Slope'].values[0],2)
-            info['OBV Signal']        = details['Signal'][0]
-            info['Passive Portfolio'] = round(details['Passive Portfolio'].values[0],2)
-            info['Active Portfolio']  = round(details['Passive Portfolio'].values[0],2)
+            info['OBV Value']               = round(details['OBV'].values[0],2)
+            info['OBV Index']               = round(details['OBV Index'].values[0],2)
+            info['OBV Slope']               = round(details['OBV Index Slope'].values[0],2)
+            info['OBV Signal']              = details['Signal'][0]
+            info['OBV Passive Portfolio']   = round(details['Passive Portfolio'].values[0],2)
+            info['OBV Active Portfolio']    = round(details['Passive Portfolio'].values[0],2)
         except:
             log.error("Error calculating OBV Results - {0}".format(self.name))
-            info['OBV Value']         = -999
-            info['OBV Index']         = -999
-            info['OBV Slope']         = -999
-            info['OBV Signal']        = ''
-            info['Passive Portfolio'] = -999
-            info['Active Portfolio']  = -999
+            info['OBV Value']               = -999
+            info['OBV Index']               = -999
+            info['OBV Slope']               = -999
+            info['OBV Signal']              = ''
+            info['OBV Passive Portfolio']   = -999
+            info['OBV Active Portfolio']    = -999
         finally:
             return info
         
@@ -539,16 +539,16 @@ class StockDetail( object ):
         info = dict()
         try:
             details = self.get_rsi_details().tail(1)
-            info['RSI Value']           = round(details['RSI'][0],2)
-            info['RSI Signal']          = details['RSI Signal'][0]
-            info['Passive Portfolio']   = round(details['Passive Portfolio'][0],2)
-            info['Active Portfolio']    = round(details['Active Portfolio'][0],2)
+            info['RSI Value']               = round(details['RSI'][0],2)
+            info['RSI Signal']              = details['RSI Signal'][0]
+            info['RSI Passive Portfolio']   = round(details['Passive Portfolio'][0],2)
+            info['RSI Active Portfolio']    = round(details['Active Portfolio'][0],2)
         except:
             log.error("Error calculating RSI Results - {0}".format(self.name))
-            info['RSI Value']           = -999
-            info['RSI Signal']          = ""
-            info['Passive Portfolio']   = -999
-            info['Active Portfolio']    = -999
+            info['RSI Value']               = -999
+            info['RSI Signal']              = ""
+            info['RSI Passive Portfolio']   = -999
+            info['RSI Active Portfolio']    = -999
         finally:
             return info
         
@@ -691,16 +691,16 @@ class StockDetail( object ):
             info['Smoothing Period']    = self._smoothing_period()
             info['Lookback Period']     = self._lookback_period()
             try:
-                info['%R'], info['%D'], info['WilliamR Signal'], info['Passive Portfolio'], info['Active Portfolio']  = self.get_williams_r_details()[2].tail(1)[['%R', '%D', 'WilliamR Signal', 'Passive Portfolio', 'Active Portfolio']].values[0]
+                info['%R'], info['%D'], info['WilliamR Signal'], info['WilliamR Passive Portfolio'], info['WilliamR Active Portfolio']  = self.get_williams_r_details()[2].tail(1)[['%R', '%D', 'WilliamR Signal', 'Passive Portfolio', 'Active Portfolio']].values[0]
             except:
-                info['%R'], info['%D'], info['WilliamR Signal'], info['Passive Portfolio'], info['Active Portfolio']  = -999, -999, "", -999,-999
+                info['%R'], info['%D'], info['WilliamR Signal'], info['WilliamR Passive Portfolio'], info['WilliamR Active Portfolio']  = -999, -999, "", -999,-999
         except:
             log.error("Error calculating William's R Results - {0}".format(self.name))
         finally:
-            info['%R'] = round(info['%R'],2)
-            info['%D'] = round(info['%D'],2)
-            info['Passive Portfolio'] = round(info['Passive Portfolio'],2)
-            info['Active Portfolio'] = round(info['Active Portfolio'],2)
+            info['%R']                          = round(info['%R'],2)
+            info['%D']                          = round(info['%D'],2)
+            info['WilliamR Passive Portfolio']  = round(info['WilliamR Passive Portfolio'],2)
+            info['WilliamR Active Portfolio']   = round(info['WilliamR Active Portfolio'],2)
             return info
         
     def get_bollinger_results(self):
@@ -1048,18 +1048,18 @@ class StockDetail( object ):
     def get_macd_results(self):
         info = dict()
         try:
-            info['MACD Line'], info['MACD Indicator'], info['MACD Line to Indicator Diff (Value)'], info['MACD Line to Indicator Diff (Days)'], info['MACD Line to Indicator Diff Rolling Peak'], info['MACD Line to Indicator Diff Rolling Peak per'], info['MACD Signal'], info['Passive Portfolio'], info['Active Portfolio'] = self.get_macd_details().tail(1)[['MACD Line', 'MACD Indicator', 'MACD Line to Indicator Diff (Value)', 'MACD Line to Indicator Diff (Days)', 'MACD Line to Indicator Diff Rolling Peak', 'MACD Line to Indicator Diff Rolling Peak per', 'MACD Signal', 'Passive Portfolio', 'Active Portfolio']].values[0]
+            info['MACD Line'], info['MACD Indicator'], info['MACD Line to Indicator Diff (Value)'], info['MACD Line to Indicator Diff (Days)'], info['MACD Line to Indicator Diff Rolling Peak'], info['MACD Line to Indicator Diff Rolling Peak per'], info['MACD Signal'], info['MACD Passive Portfolio'], info['MACD Active Portfolio'] = self.get_macd_details().tail(1)[['MACD Line', 'MACD Indicator', 'MACD Line to Indicator Diff (Value)', 'MACD Line to Indicator Diff (Days)', 'MACD Line to Indicator Diff Rolling Peak', 'MACD Line to Indicator Diff Rolling Peak per', 'MACD Signal', 'Passive Portfolio', 'Active Portfolio']].values[0]
         except:
             log.error("Error generating MacD results - {0}".format(self.name))
-            info['MACD Line'], info['MACD Indicator'], info['MACD Line to Indicator Diff (Value)'], info['MACD Line to Indicator Diff (Days)'], info['MACD Line to Indicator Diff Rolling Peak'], info['MACD Line to Indicator Diff Rolling Peak per'], info['MACD Signal'] = -1,-1,-1,-1,-1,-1,""
+            info['MACD Line'], info['MACD Indicator'], info['MACD Line to Indicator Diff (Value)'], info['MACD Line to Indicator Diff (Days)'], info['MACD Line to Indicator Diff Rolling Peak'], info['MACD Line to Indicator Diff Rolling Peak per'], info['MACD Signal'], info['MACD Passive Portfolio'], info['MACD Active Portfolio'] = -1,-1,-1,-1,-1,-1,"",-1,-1
         finally:
             info['MACD Line']                                    = round(info['MACD Line'],2)
             info['MACD Indicator']                               = round(info['MACD Indicator'],2)
             info['MACD Line to Indicator Diff (Value)']          = round(info['MACD Line to Indicator Diff (Value)'],2)
             info['MACD Line to Indicator Diff Rolling Peak']     = round(info['MACD Line to Indicator Diff Rolling Peak'],2)
             info['MACD Line to Indicator Diff Rolling Peak per'] = round(info['MACD Line to Indicator Diff Rolling Peak per'],2)
-            info['Passive Portfolio']                            = round(info['Passive Portfolio'],2)
-            info['Active Portfolio']                             = round(info['Active Portfolio'],2)
+            info['MACD Passive Portfolio']                       = round(info['MACD Passive Portfolio'],2)
+            info['MACD Active Portfolio']                        = round(info['MACD Active Portfolio'],2)
             
             return info
     def _52w_high(self):
